@@ -25,11 +25,11 @@
  */
 
 static const intel_x86_umask_t hsw_baclears[]={
-  { .uname = "ANY",
-    .udesc  = "Number of front-end re-steers due to BPU misprediction",
-    .ucode  = 0x1f00,
-    .uflags = INTEL_X86_NCOMBO | INTEL_X86_DFL,
-  },
+   { .uname  = "ANY",
+     .udesc  = "Counts the number of times the front end is re-steered, mainly when the BPU cannot provide a correct prediction and this is corrected by other branch handling mechanisms at the front end",
+     .ucode = 0x1f00,
+     .uflags= INTEL_X86_NCOMBO | INTEL_X86_DFL,
+   },
 };
 
 static const intel_x86_umask_t hsw_br_inst_exec[]={
@@ -310,7 +310,7 @@ static const intel_x86_umask_t hsw_cycle_activity[]={
      .ucntmsk= 0x4,
      .uflags = INTEL_X86_NCOMBO,
    },
-   { .uname  = "STALL_L1D_PENDING",
+   { .uname  = "STALLS_L1D_PENDING",
      .udesc  = "Executions stalls due to pending L1D load cache misses",
      .ucode  = 0x0c00 | (0xc << INTEL_X86_CMASK_BIT),
      .ucntmsk= 0x4,
@@ -467,7 +467,12 @@ static const intel_x86_umask_t hsw_icache[]={
   { .uname = "MISSES",
     .udesc  = "Number of Instruction Cache, Streaming Buffer and Victim Cache Misses. Includes Uncacheable accesses",
     .ucode  = 0x200,
-    .uflags = INTEL_X86_DFL,
+    .uflags = INTEL_X86_NCOMBO,
+  },
+  { .uname = "IFETCH_STALL",
+    .udesc  = "Number of cycles where a code-fetch stalled due to L1 instruction cache miss or an iTLB miss",
+    .ucode  = 0x400,
+    .uflags = INTEL_X86_NCOMBO,
   },
 };
 
@@ -1429,11 +1434,19 @@ static const intel_x86_umask_t hsw_offcore_response[]={
      .ucode = 1ULL << (1 + 8),
      .grpid = 0,
    },
-   { .uname  = "DMND_IFETCH",
+
+   { .uname  = "DMND_CODE_RD",
      .udesc  = "Request: number of demand and DCU prefetch instruction cacheline reads. Does not count L2 code read prefetches",
      .ucode = 1ULL << (2 + 8),
      .grpid = 0,
    },
+   { .uname  = "DMND_IFETCH",
+     .udesc  = "Request: number of demand and DCU prefetch instruction cacheline reads. Does not count L2 code read prefetches",
+     .ucode = 1ULL << (2 + 8),
+     .uequiv = "DMND_CODE_RD",
+     .grpid = 0,
+   },
+
    { .uname  = "WB",
      .udesc  = "Request: number of writebacks (modified to exclusive) transactions",
      .ucode = 1ULL << (3 + 8),
@@ -1449,31 +1462,53 @@ static const intel_x86_umask_t hsw_offcore_response[]={
      .ucode = 1ULL << (5 + 8),
      .grpid = 0,
    },
-   { .uname  = "PF_IFETCH",
+
+   { .uname  = "PF_CODE_RD",
      .udesc  = "Request: number of code reads generated by L2 prefetchers",
      .ucode = 1ULL << (6 + 8),
      .grpid = 0,
    },
-   { .uname  = "PF_LLC_DATA_RD",
-     .udesc  = "Request: number of L3 prefetcher requests to L2 for loads",
+   { .uname  = "PF_IFETCH",
+     .udesc  = "Request: number of code reads generated by L2 prefetchers",
+     .ucode = 1ULL << (6 + 8),
+     .grpid = 0,
+     .uequiv= "PF_CODE_RD",
+   },
+
+   { .uname  = "PF_L3_DATA_RD",
+     .udesc  = "Request: number of L2 prefetcher requests to L3 for loads",
      .ucode = 1ULL << (7 + 8),
      .grpid = 0,
    },
-   { .uname  = "PF_LLC_RFO",
+   { .uname  = "PF_L3_RFO",
      .udesc  = "Request: number of RFO requests generated by L2 prefetcher",
      .ucode = 1ULL << (8 + 8),
      .grpid = 0,
    },
-   { .uname  = "PF_LLC_IFETCH",
+
+   { .uname  = "PF_L3_CODE_RD",
      .udesc  = "Request: number of L2 prefetcher requests to L3 for instruction fetches",
      .ucode = 1ULL << (9 + 8),
      .grpid = 0,
    },
-   { .uname  = "BUS_LOCKS",
-     .udesc  = "Request: number bus lock and split lock requests",
+   { .uname  = "PF_L3_IFETCH",
+     .udesc  = "Request: number of L2 prefetcher requests to L3 for instruction fetches",
+     .ucode = 1ULL << (9 + 8),
+     .grpid = 0,
+     .uequiv= "PF_L3_CODE_RD",
+   },
+
+   { .uname  = "SPLIT_LOCK_UC_LOCK",
+     .udesc  = "Request: number of bus lock and split lock requests",
      .ucode = 1ULL << (10 + 8),
      .grpid = 0,
    },
+   { .uname  = "BUS_LOCKS",
+     .udesc  = "Request: number of bus lock and split lock requests",
+     .ucode = 1ULL << (10 + 8),
+     .grpid = 0,
+     .uequiv= "SPLIT_LOCK_UC_LOCK",
+   },
    { .uname  = "STRM_ST",
      .udesc  = "Request: number of streaming store requests",
      .ucode = 1ULL << (11 + 8),
@@ -1484,29 +1519,35 @@ static const intel_x86_umask_t hsw_offcore_response[]={
      .ucode = 1ULL << (15+8),
      .grpid = 0,
    },
+
+   { .uname  = "ANY_CODE_RD",
+     .udesc  = "Request: combination of PF_CODE_RD | DMND_CODE_RD | PF_L3_CODE_RD",
+     .uequiv = "PF_CODE_RD:DMND_CODE_RD:PF_L3_CODE_RD",
+     .ucode = 0x24400,
+     .grpid = 0,
+   },
    { .uname  = "ANY_IFETCH",
-     .udesc  = "Request: combination of PF_IFETCH | DMND_IFETCH | PF_LLC_IFETCH",
-     .uequiv = "PF_IFETCH:DMND_IFETCH:PF_LLC_IFETCH",
-     .ucode = 0x24100,
+     .udesc  = "Request: combination of PF_CODE_RD | PF_L3_CODE_RD",
+     .ucode = 0x24000,
      .grpid = 0,
    },
    { .uname  = "ANY_REQUEST",
      .udesc  = "Request: combination of all request umasks",
-     .uequiv = "DMND_DATA_RD:DMND_RFO:DMND_IFETCH:WB:PF_DATA_RD:PF_RFO:PF_IFETCH:PF_LLC_DATA_RD:PF_LLC_RFO:PF_LLC_IFETCH:BUS_LOCKS:STRM_ST:OTHER",
+     .uequiv = "DMND_DATA_RD:DMND_RFO:DMND_CODE_RD:WB:PF_DATA_RD:PF_RFO:PF_CODE_RD:PF_L3_DATA_RD:PF_L3_RFO:PF_L3_CODE_RD:SPLIT_LOCK_UC_LOCK:STRM_ST:OTHER",
      .ucode = 0x8fff00,
      .uflags= INTEL_X86_NCOMBO | INTEL_X86_DFL,
      .grpid = 0,
    },
    { .uname  = "ANY_DATA",
-     .udesc  = "Request: combination of DMND_DATA | PF_DATA_RD | PF_LLC_DATA_RD",
-     .uequiv = "DMND_DATA_RD:PF_DATA_RD:PF_LLC_DATA_RD",
+     .udesc  = "Request: combination of DMND_DATA | PF_DATA_RD | PF_L3_DATA_RD",
+     .uequiv = "DMND_DATA_RD:PF_DATA_RD:PF_L3_DATA_RD",
      .ucode = 0x9100,
      .grpid = 0,
    },
    { .uname  = "ANY_RFO",
-     .udesc  = "Request: combination of DMND_RFO | PF_RFO | PF_LLC_RFO",
-     .uequiv = "DMND_RFO:PF_RFO:PF_LLC_RFO",
-     .ucode = 0x10300,
+     .udesc  = "Request: combination of DMND_RFO | PF_RFO | PF_L3_RFO",
+     .uequiv = "DMND_RFO:PF_RFO:PF_L3_RFO",
+     .ucode = 0x12200,
      .grpid = 0,
    },
 
@@ -1521,60 +1562,19 @@ static const intel_x86_umask_t hsw_offcore_response[]={
      .ucode = 1ULL << (17+8),
      .grpid = 1,
    },
-   { .uname  = "LLC_HITM",
-     .udesc  = "Supplier: counts L3 hits in M-state (initial lookup)",
-     .ucode = 1ULL << (18+8),
-     .umodel = PFM_PMU_INTEL_HSW,
-     .grpid = 1,
-   },
-   { .uname  = "LLC_HITE",
-     .udesc  = "Supplier: counts L3 hits in E-state",
-     .ucode = 1ULL << (19+8),
-     .umodel = PFM_PMU_INTEL_HSW,
-     .grpid = 1,
-   },
-   { .uname  = "LLC_HITS",
-     .udesc  = "Supplier: counts L3 hits in S-state",
-     .ucode = 1ULL << (20+8),
-     .umodel = PFM_PMU_INTEL_HSW,
-     .grpid = 1,
-   },
-   { .uname  = "LLC_HITF",
-     .udesc  = "Supplier: counts L3 hits in F-state",
-     .ucode = 1ULL << (21+8),
-     .umodel = PFM_PMU_INTEL_HSW,
-     .grpid = 1,
-   },
-   { .uname  = "LLC_HITMESF",
-     .udesc  = "Supplier: counts L3 hits in any state (M, E, S, F)",
-     .ucode  = 0xfULL << (18+8),
-     .uequiv = "LLC_HITM:LLC_HITE:LLC_HITS:LLC_HITF",
-     .umodel = PFM_PMU_INTEL_HSW,
-     .grpid  = 1,
-   },
-   { .uname  = "LLC_HIT",
-     .udesc  = "Alias for LLC_HITMESF",
-     .ucode  = 0xfULL << (18+8),
-     .uequiv = "LLC_HITM:LLC_HITE:LLC_HITS:LLC_HITF",
-     .umodel = PFM_PMU_INTEL_HSW,
-     .grpid  = 1,
-   },
    { .uname  = "L3_HITM",
      .udesc  = "Supplier: counts L3 hits in M-state (initial lookup)",
      .ucode = 1ULL << (18+8),
-     .umodel = PFM_PMU_INTEL_HSW_EP,
      .grpid = 1,
    },
    { .uname  = "L3_HITE",
      .udesc  = "Supplier: counts L3 hits in E-state",
      .ucode = 1ULL << (19+8),
-     .umodel = PFM_PMU_INTEL_HSW_EP,
      .grpid = 1,
    },
    { .uname  = "L3_HITS",
      .udesc  = "Supplier: counts L3 hits in S-state",
      .ucode = 1ULL << (20+8),
-     .umodel = PFM_PMU_INTEL_HSW_EP,
      .grpid = 1,
    },
    { .uname  = "L3_HITF",
@@ -1584,75 +1584,37 @@ static const intel_x86_umask_t hsw_offcore_response[]={
      .grpid = 1,
    },
    { .uname  = "L3_HIT",
-     .udesc  = "Supplier: counts L3 hits in M, E, S, F state",
-     .ucode = 0xfULL << (18+8),
+     .udesc  = "Supplier: counts L3 hits in any state (M, E, S)",
+     .ucode  = 0x7ULL << (18+8),
+     .uequiv = "L3_HITM:L3_HITE:L3_HITS",
+     .umodel = PFM_PMU_INTEL_HSW,
+     .grpid  = 1,
+   },
+   { .uname  = "L3_HIT",
+     .udesc  = "Supplier: counts L3 hits in any state (M, E, S, F)",
+     .ucode  = 0xfULL << (18+8),
      .uequiv = "L3_HITM:L3_HITE:L3_HITS:L3_HITF",
      .umodel = PFM_PMU_INTEL_HSW_EP,
-     .grpid = 1,
-   },
-   { .uname  = "L4_HIT_LOCAL_L4",
-     .udesc  = "Supplier: counts L4 hits to local L4 cache",
-     .ucode = 0x1ULL << (22+8),
-     .umodel = PFM_PMU_INTEL_HSW_EP,
-     .grpid = 1,
-   },
-   { .uname  = "L4_HIT_REMOTE_HOP0_L4",
-     .udesc  = "Supplier: counts L4 hits to remote L4 cache with 0 hop",
-     .ucode = 0x1ULL << (23+8),
-     .umodel = PFM_PMU_INTEL_HSW_EP,
-     .grpid = 1,
-   },
-   { .uname  = "L4_HIT_REMOTE_HOP1_L4",
-     .udesc  = "Supplier: counts L4 hits to remote L4 cache with 1 hop",
-     .ucode = 0x1ULL << (24+8),
-     .umodel = PFM_PMU_INTEL_HSW_EP,
-     .grpid = 1,
-   },
-   { .uname  = "L4_HIT_REMOTE_HOP2P_L4",
-     .udesc  = "Supplier: counts L4 hits to remote L4 cache with 2P hops",
-     .ucode = 0x1ULL << (25+8),
-     .umodel = PFM_PMU_INTEL_HSW_EP,
-     .grpid = 1,
-   },
-   { .uname  = "L4_HIT",
-     .udesc  = "Supplier: counts L4 hits",
-     .ucode = 0xfULL << (22+8),
-     .uequiv = "L4_HIT_LOCAL_L4:L4_HIT_REMOTE_HOP0_L4:L4_HIT_REMOTE_HOP1_L4:L4_HIT_REMOTE_HOP2P_L4",
-     .umodel = PFM_PMU_INTEL_HSW_EP,
-     .grpid = 1,
-   },
-   { .uname  = "LLC_MISS_LOCAL",
-     .udesc  = "Supplier: counts L3 misses to local DRAM",
-     .ucode = 1ULL << (22+8),
-     .umodel = PFM_PMU_INTEL_HSW,
-     .grpid = 1,
-   },
-   { .uname  = "L3_MISS_LOCAL_DRAM",
-     .udesc  = "Supplier: counts L3 misses to local DRAM",
-     .ucode = 1ULL << (26+8),
-     .umodel = PFM_PMU_INTEL_HSW_EP,
-     .grpid = 1,
+     .grpid  = 1,
    },
    { .uname  = "L3_MISS_LOCAL",
-     .udesc  = "Supplier: Alias to L3_MISS_LOCAL_DRAM",
-     .ucode = 1ULL << (26+8),
-     .umodel = PFM_PMU_INTEL_HSW_EP,
-     .uequiv = "L3_MISS_LOCAL_DRAM",
+     .udesc  = "Supplier: counts L3 misses to local DRAM",
+     .ucode = 1ULL << (22+8),
      .grpid = 1,
    },
-   { .uname  = "L3_MISS_REMOTE_HOP0_DRAM",
+   { .uname  = "L3_MISS_REMOTE_HOP0",
      .udesc  = "Supplier: counts L3 misses to remote DRAM with 0 hop",
      .ucode = 0x1ULL << (27+8),
      .umodel = PFM_PMU_INTEL_HSW_EP,
      .grpid = 1,
    },
-   { .uname  = "L3_MISS_REMOTE_HOP1_DRAM",
+   { .uname  = "L3_MISS_REMOTE_HOP1",
      .udesc  = "Supplier: counts L3 misses to remote DRAM with 1 hop",
      .ucode = 0x1ULL << (28+8),
      .umodel = PFM_PMU_INTEL_HSW_EP,
      .grpid = 1,
    },
-   { .uname  = "L3_MISS_REMOTE_HOP2P_DRAM",
+   { .uname  = "L3_MISS_REMOTE_HOP2P",
      .udesc  = "Supplier: counts L3 misses to remote DRAM with 2P hops",
      .ucode = 0x1ULL << (29+8),
      .umodel = PFM_PMU_INTEL_HSW_EP,
@@ -1664,16 +1626,10 @@ static const intel_x86_umask_t hsw_offcore_response[]={
      .umodel = PFM_PMU_INTEL_HSW_EP,
      .grpid = 1,
    },
-   { .uname  = "L3_MISS_REMOTE_DRAM",
-     .udesc  = "Supplier: counts L3 misses to remote DRAM",
-     .ucode = 0x3ULL << (27+8),
-     .umodel = PFM_PMU_INTEL_HSW_EP,
-     .grpid = 1,
-   },
+
    { .uname  = "SPL_HIT",
-     .udesc  = "Supplier: counts L3 misses to remote DRAM",
+     .udesc  = "Supplier: counts L3 supplier hit",
      .ucode = 0x1ULL << (30+8),
-     .umodel = PFM_PMU_INTEL_HSW_EP,
      .grpid = 1,
    },
    { .uname  = "SNP_NONE",
@@ -1701,12 +1657,12 @@ static const intel_x86_umask_t hsw_offcore_response[]={
      .ucode = 1ULL << (35+8),
      .grpid = 2,
    },
-   { .uname  = "HITM",
+   { .uname  = "SNP_HITM",
      .udesc  = "Snoop: counts number of times a snoop was needed and it hitM-ed in local or remote cache",
      .ucode = 1ULL << (36+8),
      .grpid = 2,
    },
-   { .uname  = "NON_DRAM",
+   { .uname  = "SNP_NON_DRAM",
      .udesc  = "Snoop:  counts number of times target was a non-DRAM system address. This includes MMIO transactions",
      .ucode = 1ULL << (37+8),
      .grpid = 2,
@@ -1714,7 +1670,7 @@ static const intel_x86_umask_t hsw_offcore_response[]={
    { .uname  = "SNP_ANY",
      .udesc  = "Snoop: any snoop reason",
      .ucode = 0x7fULL << (31+8),
-     .uequiv = "SNP_NONE:SNP_NOT_NEEDED:SNP_MISS:SNP_NO_FWD:SNP_FWD:HITM:NON_DRAM",
+     .uequiv = "SNP_NONE:SNP_NOT_NEEDED:SNP_MISS:SNP_NO_FWD:SNP_FWD:SNP_HITM:SNP_NON_DRAM",
      .uflags= INTEL_X86_DFL,
      .grpid = 2,
    },
@@ -1812,8 +1768,8 @@ static const intel_x86_umask_t hsw_tx_mem[]={
     .ucode  = 0x100,
     .uflags = INTEL_X86_NCOMBO,
   },
-  { .uname = "ABORT_CAPACITY",
-    .udesc  = "Number of times a transactional abort was signaled due to data capacity limitation",
+  { .uname = "ABORT_CAPACITY_WRITE",
+    .udesc  = "Number of times a transactional abort was signaled due to data capacity limitation for transactional writes",
     .ucode  = 0x200,
     .uflags = INTEL_X86_NCOMBO,
   },
@@ -2034,6 +1990,22 @@ static const intel_x86_umask_t hsw_ept[]={
    },
 };
 
+static const intel_x86_umask_t hsw_arith[]={
+   { .uname  = "DIVIDER_UOPS",
+     .udesc  = "Number of uops executed by divider",
+     .ucode = 0x0200,
+     .uflags= INTEL_X86_NCOMBO | INTEL_X86_DFL,
+   },
+};
+
+static const intel_x86_umask_t hsw_offcore_requests_buffer[]={
+   { .uname  = "SQ_FULL",
+     .udesc  = "Number of cycles the offcore requests buffer is full",
+     .ucode = 0x0200,
+     .uflags= INTEL_X86_NCOMBO | INTEL_X86_DFL,
+   },
+};
+
 static const intel_x86_entry_t intel_hsw_pe[]={
   { .name   = "UNHALTED_CORE_CYCLES",
     .desc   = "Count core clock cycles whenever the clock signal on the specific core is running (not halted)",
@@ -2638,6 +2610,24 @@ static const intel_x86_entry_t intel_hsw_pe[]={
     .ngrp = 1,
     .umasks = hsw_ept,
   },
+  { .name   = "ARITH",
+    .desc   = "Counts arithmetic multiply operations",
+    .modmsk = INTEL_V4_ATTRS,
+    .cntmsk = 0xff,
+    .code = 0x14,
+    .numasks = LIBPFM_ARRAY_SIZE(hsw_arith),
+    .ngrp = 1,
+    .umasks = hsw_arith,
+  },
+  { .name   = "OFFCORE_REQUESTS_BUFFER",
+    .desc   = "Offcore reqest buffer",
+    .modmsk = INTEL_V4_ATTRS,
+    .cntmsk = 0xff,
+    .code = 0xb2,
+    .numasks = LIBPFM_ARRAY_SIZE(hsw_offcore_requests_buffer),
+    .ngrp = 1,
+    .umasks = hsw_offcore_requests_buffer,
+  },
   { .name   = "OFFCORE_RESPONSE_0",
     .desc   = "Offcore response event (must provide at least one request type and either any_response or any combination of supplier + snoop)",
     .modmsk = INTEL_V4_ATTRS,
