@@ -98,6 +98,8 @@ static pfmlib_pmu_t *pfmlib_pmus[]=
 	&intel_ivb_unc_cbo3_support,
 	&intel_ivb_ep_support,
 	&intel_hsw_support,
+	&intel_hsw_ep_support,
+	&intel_bdw_support,
 	&intel_rapl_support,
 	&intel_snbep_unc_cb0_support,
 	&intel_snbep_unc_cb1_support,
@@ -202,10 +204,12 @@ static pfmlib_pmu_t *pfmlib_pmus[]=
 	&arm_qcom_krait_support,
 	&arm_cortex_a57_support,
 	&arm_cortex_a53_support,
+	&arm_xgene_support,
 #endif
 #ifdef CONFIG_PFMLIB_ARCH_ARM64
 	&arm_cortex_a57_support,
 	&arm_cortex_a53_support,
+	&arm_xgene_support,
 #endif
 
 #ifdef CONFIG_PFMLIB_ARCH_S390X
@@ -586,7 +590,7 @@ pfmlib_build_fstr(pfmlib_event_desc_t *e, char **fstr)
 	if (*fstr)
 		sprintf(*fstr, "%s::%s", e->pmu->name, e->fstr);
 
-	return fstr ? PFM_SUCCESS : PFM_ERR_NOMEM;
+	return *fstr ? PFM_SUCCESS : PFM_ERR_NOMEM;
 }
 
 static int
@@ -808,8 +812,16 @@ pfm_find_event(const char *str)
 	memset(&e, 0, sizeof(e));
 
 	ret = pfmlib_parse_event(str, &e);
-	if (ret == PFM_SUCCESS)
-		return pfmlib_pidx2idx(e.pmu, e.event);
+	if (ret == PFM_SUCCESS) {
+		/*
+		 * save index so we can return it
+		 * and free the pattrs data that was
+		 * allocated in pfmlib_parse_event()
+		 */
+		ret = pfmlib_pidx2idx(e.pmu, e.event);
+
+		pfmlib_release_event(&e);
+	}
 
 	return ret;
 }
@@ -945,7 +957,7 @@ found_attr:
 		if (type != PFM_ATTR_UMASK && type != PFM_ATTR_RAW_UMASK && !has_val) {
 			if (type != PFM_ATTR_MOD_BOOL)
 				return PFM_ERR_ATTR_VAL;
-			has_val = 1; s = yes; /* no const */
+			s = yes; /* no const */
 			goto handle_bool;
 		}
 
@@ -1871,7 +1883,8 @@ pfmlib_raw_pmu_encode(void *this, const char *str, int dfl_plm, void *data)
 
 	if (!pmu->get_event_encoding[PFM_OS_NONE]) {
 		DPRINT("PMU %s does not support PFM_OS_NONE\n", pmu->name);
-		return PFM_ERR_NOTSUPP;
+		ret = PFM_ERR_NOTSUPP;
+		goto error;
 	}
 
 	ret = pmu->get_event_encoding[PFM_OS_NONE](pmu, &e);
