@@ -1251,7 +1251,7 @@ static const test_event_t x86_test_events[]={
 	  .count = 2,
 	  .codes[0] = 0x334,
 	  .codes[1] = 0x7c0000,
-	  .fstr = "snbep_unc_cbo0::UNC_C_LLC_LOOKUP:DATA_READ:STATE_MESIF:e=0:i=0:t=0:tf=0",
+	  .fstr = "snbep_unc_cbo0::UNC_C_LLC_LOOKUP:DATA_READ:STATE_MESIF:e=0:i=0:t=0:tf=0:cf=0",
 	},
 	{ SRC_LINE,
 	  .name = "snbep_unc_cbo0::UNC_C_LLC_LOOKUP:ANY",
@@ -1259,7 +1259,7 @@ static const test_event_t x86_test_events[]={
 	  .count = 2,
 	  .codes[0] = 0x1f34,
 	  .codes[1] = 0x7c0000,
-	  .fstr = "snbep_unc_cbo0::UNC_C_LLC_LOOKUP:ANY:STATE_MESIF:e=0:i=0:t=0:tf=0",
+	  .fstr = "snbep_unc_cbo0::UNC_C_LLC_LOOKUP:ANY:STATE_MESIF:e=0:i=0:t=0:tf=0:cf=0",
 	},
 	{ SRC_LINE,
 	  .name = "snbep_unc_cbo0::UNC_C_LLC_LOOKUP:DATA_READ:nf=1",
@@ -1283,7 +1283,7 @@ static const test_event_t x86_test_events[]={
 	  .count = 2,
 	  .codes[0] = 0x4334,
 	  .codes[1] = 0x7c0c00,
-	  .fstr = "snbep_unc_cbo0::UNC_C_LLC_LOOKUP:DATA_READ:NID:STATE_MESIF:e=0:i=0:t=0:tf=0:nf=3",
+	  .fstr = "snbep_unc_cbo0::UNC_C_LLC_LOOKUP:DATA_READ:NID:STATE_MESIF:e=0:i=0:t=0:tf=0:cf=0:nf=3",
 	},
 	{ SRC_LINE,
 	  .name = "snbep_unc_cbo0::UNC_C_LLC_LOOKUP:NID:STATE_M:nf=3",
@@ -1291,7 +1291,7 @@ static const test_event_t x86_test_events[]={
 	  .count = 2,
 	  .codes[0] = 0x4334,
 	  .codes[1] = 0x200c00,
-	  .fstr = "snbep_unc_cbo0::UNC_C_LLC_LOOKUP:DATA_READ:NID:STATE_M:e=0:i=0:t=0:tf=0:nf=3",
+	  .fstr = "snbep_unc_cbo0::UNC_C_LLC_LOOKUP:DATA_READ:NID:STATE_M:e=0:i=0:t=0:tf=0:cf=0:nf=3",
 	},
 	{ SRC_LINE,
 	  .name = "snbep_unc_cbo0::UNC_C_LLC_LOOKUP:NID:nf=3:tid=1",
@@ -1306,7 +1306,7 @@ static const test_event_t x86_test_events[]={
 	  .ret  = PFM_SUCCESS,
 	  .count = 1,
 	  .codes[0] = 0x1035,
-	  .fstr = "snbep_unc_cbo0::UNC_C_TOR_INSERTS:WB:e=0:i=0:t=0:tf=0",
+	  .fstr = "snbep_unc_cbo0::UNC_C_TOR_INSERTS:WB:e=0:i=0:t=0:tf=0:cf=0",
 	},
 	{ SRC_LINE,
 	  .name = "snbep_unc_cbo0::UNC_C_TOR_INSERTS:OPCODE:OPC_PCIWILF",
@@ -1314,7 +1314,7 @@ static const test_event_t x86_test_events[]={
 	  .count = 2,
 	  .codes[0] = 0x135,
 	  .codes[1] = 0xca000000,
-	  .fstr = "snbep_unc_cbo0::UNC_C_TOR_INSERTS:OPCODE:OPC_PCIWILF:e=0:i=0:t=0:tf=0",
+	  .fstr = "snbep_unc_cbo0::UNC_C_TOR_INSERTS:OPCODE:OPC_PCIWILF:e=0:i=0:t=0:tf=0:cf=0",
 	},
 	{ SRC_LINE,
 	  .name = "snbep_unc_cbo0::UNC_C_TOR_INSERTS:OPCODE:OPC_PCIWILF:nf=1",
@@ -1326,7 +1326,7 @@ static const test_event_t x86_test_events[]={
 	  .count = 2,
 	  .codes[0] = 0x4135,
 	  .codes[1] = 0xcf000400,
-	  .fstr = "snbep_unc_cbo0::UNC_C_TOR_INSERTS:NID_OPCODE:OPC_PCIRDCUR:e=0:i=0:t=0:tf=0:nf=1",
+	  .fstr = "snbep_unc_cbo0::UNC_C_TOR_INSERTS:NID_OPCODE:OPC_PCIRDCUR:e=0:i=0:t=0:tf=0:cf=0:nf=1",
 	},
 	{ SRC_LINE,
 	  .name = "snbep_unc_cbo0::UNC_C_TOR_INSERTS:OPC_RFO:NID_OPCODE:nf=1",
@@ -1334,7 +1334,7 @@ static const test_event_t x86_test_events[]={
 	  .count = 2,
 	  .codes[0] = 0x4135,
 	  .codes[1] = 0xc0000400,
-	  .fstr = "snbep_unc_cbo0::UNC_C_TOR_INSERTS:NID_OPCODE:OPC_RFO:e=0:i=0:t=0:tf=0:nf=1",
+	  .fstr = "snbep_unc_cbo0::UNC_C_TOR_INSERTS:NID_OPCODE:OPC_RFO:e=0:i=0:t=0:tf=0:cf=0:nf=1",
 	},
 	{ SRC_LINE,
 	  .name = "snbep_unc_ha::UNC_H_CLOCKTICKS",
@@ -2039,19 +2039,19 @@ static const test_event_t x86_test_events[]={
 	{ SRC_LINE,
 	  .name = "hsw::inst_Retired:any_p:intx",
 	  .count = 1,
-	  .codes[0] = 0x1005300c0,
+	  .codes[0] = 0x1005300c0ull,
 	  .fstr = "hsw::INST_RETIRED:ANY_P:k=1:u=1:e=0:i=0:c=0:t=0:intx=1:intxcp=0",
 	},
 	{ SRC_LINE,
 	  .name = "hsw::inst_Retired:any_p:intx:intxcp",
 	  .count = 1,
-	  .codes[0] = 0x3005300c0,
+	  .codes[0] = 0x3005300c0ull,
 	  .fstr = "hsw::INST_RETIRED:ANY_P:k=1:u=1:e=0:i=0:c=0:t=0:intx=1:intxcp=1",
 	},
 	{ SRC_LINE,
 	  .name = "hsw::inst_Retired:any_p:intx=0:intxcp",
 	  .count = 1,
-	  .codes[0] = 0x2005300c0,
+	  .codes[0] = 0x2005300c0ull,
 	  .fstr = "hsw::INST_RETIRED:ANY_P:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=1",
 	},
 	{ SRC_LINE,
@@ -2079,6 +2079,74 @@ static const test_event_t x86_test_events[]={
 	  .codes[0] = 0x5304c9,
 	  .fstr = "hsw::RTM_RETIRED:ABORTED:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=0",
 	},
+	{ SRC_LINE,
+	  .name = "hsw::offcore_response_0:k:intx=1",
+	  .ret  = PFM_SUCCESS,
+	  .count = 2,
+	  .codes[0] = 0x1005201b7ull,
+	  .codes[1] = 0x18fff,
+	  .fstr = "hsw::OFFCORE_RESPONSE_0:ANY_REQUEST:ANY_RESPONSE:k=1:u=0:e=0:i=0:c=0:t=0:intx=1:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "hsw::offcore_response_0:any_request",
+	  .ret  = PFM_SUCCESS,
+	  .count = 2,
+	  .codes[0] = 0x5301b7,
+	  .codes[1] = 0x18fff,
+	  .fstr = "hsw::OFFCORE_RESPONSE_0:DMND_DATA_RD:DMND_RFO:DMND_CODE_RD:WB:PF_DATA_RD:PF_RFO:PF_CODE_RD:PF_L3_DATA_RD:PF_L3_RFO:PF_L3_CODE_RD:SPLIT_LOCK_UC_LOCK:STRM_ST:OTHER:ANY_RESPONSE:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "hsw::offcore_response_0:any_request:any_response:L3_MISS_LOCAL",
+	  .ret  = PFM_ERR_FEATCOMB,
+	},
+	{ SRC_LINE,
+	  .name = "hsw::offcore_response_0:split_lock_uc_lock",
+	  .ret  = PFM_SUCCESS,
+	  .count = 2,
+	  .codes[0] = 0x5301b7,
+	  .codes[1] = 0x10400,
+	  .fstr = "hsw::OFFCORE_RESPONSE_0:SPLIT_LOCK_UC_LOCK:ANY_RESPONSE:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "hsw::offcore_response_0:any_ifetch",
+	  .ret  = PFM_SUCCESS,
+	  .count = 2,
+	  .codes[0] = 0x5301b7,
+	  .codes[1] = 0x10240,
+	  .fstr = "hsw::OFFCORE_RESPONSE_0:ANY_IFETCH:ANY_RESPONSE:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "hsw::offcore_response_0:L3_HITF",
+	  .ret  = PFM_ERR_ATTR,
+	},
+	{ SRC_LINE,
+	  .name = "hsw::offcore_response_0:LLC_MISS_LOCAL",
+	  .ret  = PFM_ERR_ATTR,
+	},
+	{ SRC_LINE,
+	  .name = "hsw::offcore_response_0:L3_HIT:u",
+	  .ret  = PFM_SUCCESS,
+	  .count = 2,
+	  .codes[0] = 0x5101b7,
+	  .codes[1] = 0x3f801c8fffull,
+	  .fstr = "hsw::OFFCORE_RESPONSE_0:ANY_REQUEST:L3_HITM:L3_HITE:L3_HITS:SNP_ANY:k=0:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "hsw::offcore_response_0:ANY_DATA",
+	  .ret  = PFM_SUCCESS,
+	  .count = 2,
+	  .codes[0] = 0x5301b7,
+	  .codes[1] = 0x10091,
+	  .fstr = "hsw::OFFCORE_RESPONSE_0:DMND_DATA_RD:PF_DATA_RD:PF_L3_DATA_RD:ANY_RESPONSE:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "hsw::offcore_response_0:DMND_DATA_RD:L3_HITS:SNP_FWD",
+	  .ret  = PFM_SUCCESS,
+	  .count = 2,
+	  .codes[0] = 0x5301b7,
+	  .codes[1] = 0x800100001ull,
+	  .fstr = "hsw::OFFCORE_RESPONSE_0:DMND_DATA_RD:L3_HITS:SNP_FWD:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=0",
+	},
 	{ SRC_LINE,
 	  .name = "ivb_unc_cbo0::unc_clockticks",
 	  .ret  = PFM_SUCCESS,
@@ -2246,7 +2314,7 @@ static const test_event_t x86_test_events[]={
 	  .count = 2,
 	  .codes[0] = 0x334,
 	  .codes[1] = 0x7e0000,
-	  .fstr = "ivbep_unc_cbo0::UNC_C_LLC_LOOKUP:DATA_READ:STATE_MESIF:e=0:t=0:tf=0",
+	  .fstr = "ivbep_unc_cbo0::UNC_C_LLC_LOOKUP:DATA_READ:STATE_MESIF:e=0:t=0:tf=0:cf=0",
 	},
 	{ SRC_LINE,
 	  .name = "ivbep_unc_cbo0::UNC_C_LLC_LOOKUP:DATA_READ:nf=1",
@@ -2258,7 +2326,7 @@ static const test_event_t x86_test_events[]={
 	  .count = 2,
 	  .codes[0] = 0x1134,
 	  .codes[1] = 0x7e0000,
-	  .fstr = "ivbep_unc_cbo0::UNC_C_LLC_LOOKUP:ANY:STATE_MESIF:e=0:t=0:tf=0",
+	  .fstr = "ivbep_unc_cbo0::UNC_C_LLC_LOOKUP:ANY:STATE_MESIF:e=0:t=0:tf=0:cf=0",
 	},
 	{ SRC_LINE,
 	  .name = "ivbep_unc_cbo0::UNC_C_LLC_LOOKUP:NID:STATE_M",
@@ -2271,7 +2339,7 @@ static const test_event_t x86_test_events[]={
 	  .codes[0] = 0x5134,
 	  .codes[1] = 0x7e0000,
 	  .codes[2] = 0x3,
-	  .fstr = "ivbep_unc_cbo0::UNC_C_LLC_LOOKUP:ANY:NID:STATE_MESIF:e=0:t=0:tf=0:nf=3",
+	  .fstr = "ivbep_unc_cbo0::UNC_C_LLC_LOOKUP:ANY:NID:STATE_MESIF:e=0:t=0:tf=0:cf=0:nf=3",
 	},
 	{ SRC_LINE,
 	  .name = "ivbep_unc_cbo0::UNC_C_LLC_LOOKUP:NID:STATE_M:tid=1",
@@ -2288,7 +2356,7 @@ static const test_event_t x86_test_events[]={
 	  .codes[0] = 0x10c4534,
 	  .codes[1] = 0x7e0001,
 	  .codes[2] = 0x3,
-	  .fstr = "ivbep_unc_cbo0::UNC_C_LLC_LOOKUP:WRITE:NID:STATE_MESIF:e=1:t=1:tf=1:nf=3",
+	  .fstr = "ivbep_unc_cbo0::UNC_C_LLC_LOOKUP:WRITE:NID:STATE_MESIF:e=1:t=1:tf=1:cf=0:nf=3",
 	},
 	{ SRC_LINE,
 	  .name = "ivbep_unc_cbo0::UNC_C_LLC_VICTIMS",
@@ -2307,14 +2375,14 @@ static const test_event_t x86_test_events[]={
 	  .ret  = PFM_SUCCESS,
 	  .count = 1,
 	  .codes[0] = 0x137,
-	  .fstr = "ivbep_unc_cbo0::UNC_C_LLC_VICTIMS:STATE_M:e=0:t=0:tf=0",
+	  .fstr = "ivbep_unc_cbo0::UNC_C_LLC_VICTIMS:STATE_M:e=0:t=0:tf=0:cf=0",
 	},
 	{ SRC_LINE,
 	  .name = "ivbep_unc_cbo0::UNC_C_LLC_VICTIMS:STATE_M:STATE_S",
 	  .ret  = PFM_SUCCESS,
 	  .count = 1,
 	  .codes[0] = 0x537,
-	  .fstr = "ivbep_unc_cbo0::UNC_C_LLC_VICTIMS:STATE_M:STATE_S:e=0:t=0:tf=0",
+	  .fstr = "ivbep_unc_cbo0::UNC_C_LLC_VICTIMS:STATE_M:STATE_S:e=0:t=0:tf=0:cf=0",
 	},
 	{ SRC_LINE,
 	  .name = "ivbep_unc_cbo0::UNC_C_LLC_VICTIMS:STATE_M:STATE_S:NID:nf=1",
@@ -2323,7 +2391,7 @@ static const test_event_t x86_test_events[]={
 	  .codes[0] = 0x4537,
 	  .codes[1] = 0x0,
 	  .codes[2] = 0x1,
-	  .fstr = "ivbep_unc_cbo0::UNC_C_LLC_VICTIMS:STATE_M:STATE_S:NID:e=0:t=0:tf=0:nf=1",
+	  .fstr = "ivbep_unc_cbo0::UNC_C_LLC_VICTIMS:STATE_M:STATE_S:NID:e=0:t=0:tf=0:cf=0:nf=1",
 	},
 	{ SRC_LINE,
 	  .name = "ivbep_unc_cbo0::UNC_C_TOR_INSERTS:OPCODE",
@@ -2334,7 +2402,7 @@ static const test_event_t x86_test_events[]={
 	  .ret  = PFM_SUCCESS,
 	  .count = 1,
 	  .codes[0] = 0x1035,
-	  .fstr = "ivbep_unc_cbo0::UNC_C_TOR_INSERTS:WB:e=0:t=0:tf=0",
+	  .fstr = "ivbep_unc_cbo0::UNC_C_TOR_INSERTS:WB:e=0:t=0:tf=0:cf=0:isoc=0:nc=0",
 	},
 	{ SRC_LINE,
 	  .name = "ivbep_unc_cbo0::UNC_C_TOR_INSERTS:OPCODE:OPC_PCIWILF",
@@ -2343,7 +2411,16 @@ static const test_event_t x86_test_events[]={
 	  .codes[0] = 0x135,
 	  .codes[1] = 0x0,
 	  .codes[2] = 0x19400000ull,
-	  .fstr = "ivbep_unc_cbo0::UNC_C_TOR_INSERTS:OPCODE:OPC_PCIWILF:e=0:t=0:tf=0",
+	  .fstr = "ivbep_unc_cbo0::UNC_C_TOR_INSERTS:OPCODE:OPC_PCIWILF:e=0:t=0:tf=0:cf=0:isoc=0:nc=0",
+	},
+	{ SRC_LINE,
+	  .name = "ivbep_unc_cbo0::UNC_C_TOR_INSERTS:OPCODE:OPC_PCIWILF:isoc=1",
+	  .ret  = PFM_SUCCESS,
+	  .count = 3,
+	  .codes[0] = 0x135,
+	  .codes[1] = 0x0,
+	  .codes[2] = 0x99400000ull,
+	  .fstr = "ivbep_unc_cbo0::UNC_C_TOR_INSERTS:OPCODE:OPC_PCIWILF:e=0:t=0:tf=0:cf=0:isoc=1:nc=0",
 	},
 	{ SRC_LINE,
 	  .name = "ivbep_unc_cbo0::UNC_C_TOR_INSERTS:OPCODE:OPC_PCIWILF:nf=1",
@@ -2356,7 +2433,7 @@ static const test_event_t x86_test_events[]={
 	  .codes[0] = 0x4135,
 	  .codes[1] = 0x0,
 	  .codes[2] = 0x19e00001ull,
-	  .fstr = "ivbep_unc_cbo0::UNC_C_TOR_INSERTS:NID_OPCODE:OPC_PCIRDCUR:e=0:t=0:tf=0:nf=1",
+	  .fstr = "ivbep_unc_cbo0::UNC_C_TOR_INSERTS:NID_OPCODE:OPC_PCIRDCUR:e=0:t=0:tf=0:cf=0:nf=1:isoc=0:nc=0",
 	},
 	{ SRC_LINE,
 	  .name = "ivbep_unc_cbo0::UNC_C_TOR_INSERTS:OPC_RFO:NID_OPCODE:nf=1",
@@ -2365,14 +2442,14 @@ static const test_event_t x86_test_events[]={
 	  .codes[0] = 0x4135,
 	  .codes[1] = 0x0,
 	  .codes[2] = 0x18000001ull,
-	  .fstr = "ivbep_unc_cbo0::UNC_C_TOR_INSERTS:NID_OPCODE:OPC_RFO:e=0:t=0:tf=0:nf=1",
+	  .fstr = "ivbep_unc_cbo0::UNC_C_TOR_INSERTS:NID_OPCODE:OPC_RFO:e=0:t=0:tf=0:cf=0:nf=1:isoc=0:nc=0",
 	},
 	{ SRC_LINE,
 	  .name = "ivbep_unc_cbo0::UNC_C_TOR_OCCUPANCY:MISS_REMOTE",
 	  .ret  = PFM_SUCCESS,
 	  .count = 1,
 	  .codes[0] = 0x8a36,
-	  .fstr = "ivbep_unc_cbo0::UNC_C_TOR_OCCUPANCY:MISS_REMOTE:e=0:t=0:tf=0",
+	  .fstr = "ivbep_unc_cbo0::UNC_C_TOR_OCCUPANCY:MISS_REMOTE:e=0:t=0:tf=0:cf=0:isoc=0:nc=0",
 	},
 	{ SRC_LINE,
 	  .name = "ivbep_unc_pcu::UNC_P_CLOCKTICKS",
@@ -2702,8 +2779,194 @@ static const test_event_t x86_test_events[]={
 	  .codes[0] = 0x25,
 	  .fstr = "ivbep_unc_r3qpi1::UNC_R3_TXR_CYCLES_FULL:e=0:t=0",
 	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::mem_trans_retired:latency_above_threshold:ldlat=3:u",
+	  .ret = PFM_SUCCESS,
+	  .count = 2,
+	  .codes[0] = 0x5101cd,
+	  .codes[1] = 3,
+	  .fstr = "hsw_ep::MEM_TRANS_RETIRED:LOAD_LATENCY:k=0:u=1:e=0:i=0:c=0:t=0:ldlat=3:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::mem_trans_retired:latency_above_threshold:ldlat=1000000",
+	  .ret = PFM_ERR_ATTR_VAL,
+	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::mem_trans_retired:load_latency",
+	  .ret = PFM_SUCCESS,
+	  .count = 2,
+	  .codes[0] = 0x5301cd,
+	  .codes[1] = 3,
+	  .fstr = "hsw_ep::MEM_TRANS_RETIRED:LOAD_LATENCY:k=1:u=1:e=0:i=0:c=0:t=0:ldlat=3:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::mem_trans_retired:load_latency:ldlat=1000000",
+	  .ret = PFM_ERR_ATTR_VAL,
+	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::mem_trans_retired:latency_above_threshold:ldlat=2:intx=0:intxcp=0",
+	  .ret = PFM_ERR_ATTR_VAL,
+	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::inst_Retired:any_p:intx",
+	  .count = 1,
+	  .codes[0] = 0x1005300c0ull,
+	  .fstr = "hsw_ep::INST_RETIRED:ANY_P:k=1:u=1:e=0:i=0:c=0:t=0:intx=1:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::inst_Retired:any_p:intx:intxcp",
+	  .count = 1,
+	  .codes[0] = 0x3005300c0ull,
+	  .fstr = "hsw_ep::INST_RETIRED:ANY_P:k=1:u=1:e=0:i=0:c=0:t=0:intx=1:intxcp=1",
+	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::inst_Retired:any_p:intx=0:intxcp",
+	  .count = 1,
+	  .codes[0] = 0x2005300c0ull,
+	  .fstr = "hsw_ep::INST_RETIRED:ANY_P:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=1",
+	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::cycle_activity:cycles_l2_pending",
+	  .ret = PFM_SUCCESS,
+	  .count = 1,
+	  .codes[0] = 0x15301a3,
+	  .fstr = "hsw_ep::CYCLE_ACTIVITY:CYCLES_L2_PENDING:k=1:u=1:e=0:i=0:t=0:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::cycle_activity:cycles_l2_pending:c=8",
+	  .ret = PFM_ERR_ATTR,
+	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::hle_retired:aborted",
+	  .ret = PFM_SUCCESS,
+	  .count = 1,
+	  .codes[0] = 0x5304c8,
+	  .fstr = "hsw_ep::HLE_RETIRED:ABORTED:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::mem_load_uops_l3_miss_retired:remote_dram",
+	  .ret = PFM_SUCCESS,
+	  .count = 1,
+	  .codes[0] = 0x5304d3,
+	  .fstr = "hsw_ep::MEM_LOAD_UOPS_L3_MISS_RETIRED:REMOTE_DRAM:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::offcore_response_0:any_data:L3_miss_local",
+	  .ret = PFM_SUCCESS,
+	  .count = 2,
+	  .codes[0] = 0x5301b7,
+	  .codes[1] = 0x3f80400091ull,
+	  .fstr = "hsw_ep::OFFCORE_RESPONSE_0:DMND_DATA_RD:PF_DATA_RD:PF_L3_DATA_RD:L3_MISS_LOCAL:SNP_ANY:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::offcore_response_0:any_data:LLC_miss_local",
+	  .ret = PFM_ERR_ATTR,
+	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::offcore_response_0:any_data:LLC_miss_remote",
+	  .ret = PFM_ERR_ATTR,
+	},
+	{ SRC_LINE,
+	  .name = "hsw_ep::offcore_response_0:any_data:L3_HIT",
+	  .ret = PFM_SUCCESS,
+	  .count = 2,
+	  .codes[0] =0x5301b7,
+	  .codes[1] =0x3f803c0091ull,
+	  .fstr = "hsw_ep::OFFCORE_RESPONSE_0:DMND_DATA_RD:PF_DATA_RD:PF_L3_DATA_RD:L3_HITM:L3_HITE:L3_HITS:L3_HITF:SNP_ANY:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "bdw::mem_trans_retired:latency_above_threshold:ldlat=3:u",
+	  .ret = PFM_SUCCESS,
+	  .count = 2,
+	  .codes[0] = 0x5101cd,
+	  .codes[1] = 3,
+	  .fstr = "bdw::MEM_TRANS_RETIRED:LOAD_LATENCY:k=0:u=1:e=0:i=0:c=0:t=0:ldlat=3:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "bdw::mem_trans_retired:latency_above_threshold:ldlat=1000000",
+	  .ret = PFM_ERR_ATTR_VAL,
+	},
+	{ SRC_LINE,
+	  .name = "bdw::mem_trans_retired:load_latency",
+	  .ret = PFM_SUCCESS,
+	  .count = 2,
+	  .codes[0] = 0x5301cd,
+	  .codes[1] = 3,
+	  .fstr = "bdw::MEM_TRANS_RETIRED:LOAD_LATENCY:k=1:u=1:e=0:i=0:c=0:t=0:ldlat=3:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "bdw::mem_trans_retired:load_latency:ldlat=1000000",
+	  .ret = PFM_ERR_ATTR_VAL,
+	},
+	{ SRC_LINE,
+	  .name = "bdw::mem_trans_retired:latency_above_threshold:ldlat=2:intx=0:intxcp=0",
+	  .ret = PFM_ERR_ATTR_VAL,
+	},
+	{ SRC_LINE,
+	  .name = "bdw::inst_Retired:any_p:intx",
+	  .count = 1,
+	  .codes[0] = 0x1005300c0ull,
+	  .fstr = "bdw::INST_RETIRED:ANY_P:k=1:u=1:e=0:i=0:c=0:t=0:intx=1:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "bdw::inst_Retired:any_p:intx:intxcp",
+	  .count = 1,
+	  .codes[0] = 0x3005300c0ull,
+	  .fstr = "bdw::INST_RETIRED:ANY_P:k=1:u=1:e=0:i=0:c=0:t=0:intx=1:intxcp=1",
+	},
+	{ SRC_LINE,
+	  .name = "bdw::inst_Retired:any_p:intx=0:intxcp",
+	  .count = 1,
+	  .codes[0] = 0x2005300c0ull,
+	  .fstr = "bdw::INST_RETIRED:ANY_P:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=1",
+	},
+	{ SRC_LINE,
+	  .name = "bdw::cycle_activity:cycles_l2_pending",
+	  .ret = PFM_SUCCESS,
+	  .count = 1,
+	  .codes[0] = 0x15301a3,
+	  .fstr = "bdw::CYCLE_ACTIVITY:CYCLES_L2_PENDING:k=1:u=1:e=0:i=0:t=0:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "bdw::cycle_activity:cycles_l2_pending:c=8",
+	  .ret = PFM_ERR_ATTR,
+	},
+	{ SRC_LINE,
+	  .name = "bdw::hle_retired:aborted",
+	  .ret = PFM_SUCCESS,
+	  .count = 1,
+	  .codes[0] = 0x5304c8,
+	  .fstr = "bdw::HLE_RETIRED:ABORTED:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "bdw::rtm_retired:aborted",
+	  .ret = PFM_SUCCESS,
+	  .count = 1,
+	  .codes[0] = 0x5304c9,
+	  .fstr = "bdw::RTM_RETIRED:ABORTED:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "bdw::arith:fpu_div_active",
+	  .ret = PFM_SUCCESS,
+	  .count = 1,
+	  .codes[0] = 0x530114,
+	  .fstr = "bdw::ARITH:FPU_DIV_ACTIVE:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "bdw::inst_retired:prec_dist",
+	  .ret = PFM_SUCCESS,
+	  .count = 1,
+	  .codes[0] = 0x5301c0,
+	  .fstr = "bdw::INST_RETIRED:PREC_DIST:k=1:u=1:e=0:i=0:c=0:t=0:intx=0:intxcp=0",
+	},
+	{ SRC_LINE,
+	  .name = "bdw::rs_events:empty_end",
+	  .ret = PFM_SUCCESS,
+	  .count = 1,
+	  .codes[0] = 0x1d7015e,
+	  .fstr = "bdw::RS_EVENTS:EMPTY_END:k=1:u=1:e=1:i=1:c=1:t=0:intx=0:intxcp=0",
+	},
 };
-
 #define NUM_TEST_EVENTS (int)(sizeof(x86_test_events)/sizeof(test_event_t))
 
 static int
